@@ -46,15 +46,14 @@ def add_text(ifile, ofile, text, padding=100):
     myFont = ImageFont.truetype('ariblk.ttf', 48)
 
     text_length = len(text)
-    if text_length > 75:
-        start_px = width/10
-    elif text_length > 65:
-        start_px = width/8
-    elif text_length > 55:
-        start_px = width/6
-    else:
+    print("title:", text, 'length:', text_length)
+    if text_length > 100:
+        start_px = 10
+    elif text_length <= 100 and text_length >= 70:
+        start_px = width * (1 - text_length / 100)
+    elif text_length < 70 and text_length > 0:
         start_px = width/4
     
     # Add Text to an image
-    I1.text((width/4, 20), text, font=myFont, fill =(0, 0, 0))
+    I1.text((start_px, 20), text, font=myFont, fill =(0, 0, 0))
     result.save(ofile)
